/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: i18n_l.h 197 2005-01-22 20:40:33Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_I18N_L_H
#define AQBANKING_I18N_L_H

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif


#ifdef HAVE_I18N
# ifdef HAVE_LOCALE_H
#  include <locale.h>
# endif
# ifdef HAVE_LIBINTL_H
#  include <libintl.h>
# endif

# define I18N(msg) dgettext(PACKAGE, msg)
#else
# define I18N(msg) msg
#endif

#define I18N_NOOP(msg) msg



#endif /* AQBANKING_I18N_L_H */
